# Journal definitions

This collection defines types, views and fields that can be used to incorporate references to uploaded, imported or linked media resources into entity views, and also defines a "Journal" type that can be used to record (mostly) unstructured information about some process, along with associated resources.


